@@ -14,7 +14,7 @@ Readonly::Array our @EXPORT_OK => qw(attribute char comment end_element instruct
 	start_element);
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Encode attribute as PYX.
 sub attribute {
@@ -162,19 +162,16 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<App::SGML2PYX>,
-L<PYX::Checker>,
-L<PYX::Filter>,
 L<PYX::GraphViz>,
-L<PYX::Optimalization>,
+L<PYX::Hist>,
 L<PYX::Parser>,
-L<PYX::Sort>,
 L<PYX::Stack>,
 L<PYX::Utils>,
-L<PYX::Write::Raw>,
-L<PYX::Write::Tags>,
-L<PYX::Write::Tags::Code>,
-L<PYX::XMLNorm>.
+L<Task::PYX>.
+
+=head1 REPOSITORY
+
+L<https://github.com/tupinek/PYX>
 
 =head1 AUTHOR
 
@@ -189,6 +186,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
