@@ -13,7 +13,7 @@ use Readonly;
 Readonly::Scalar my $EMPTY_STR => q{};
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -60,6 +60,12 @@ sub new {
 	return $self;
 }
 
+# Get actual parsing line.
+sub line {
+	my $self = shift;
+	return $self->{'_line'};
+}
+
 # Parse PYX text or array of PYX text.
 sub parse {
 	my ($self, $pyx, $out) = @_;
@@ -204,6 +210,7 @@ PYX::Parser - PYX parser with callbacks.
 
  use PYX::Parser;
  my $obj = PYX::Parser->new(%parameters);
+ my $line = $obj->line;
  $obj->parse($pyx, $out);
  $obj->parse_file($input_file, $out);
  $obj->parse_handle($input_file_handler, $out);
@@ -294,6 +301,11 @@ PYX::Parser - PYX parser with callbacks.
 
 =back
 
+=item C<line()>
+
+ Get actual parsing line.
+ Returns string.
+
 =item C<parse($pyx[, $out])>
 
  Parse PYX text or array of PYX text.
@@ -387,7 +399,15 @@ L<Error::Pure>.
 =head1 SEE ALSO
 
 L<PYX>,
-L<PYX::Utils>.
+L<PYX::GraphViz>,
+L<PYX::Hist>,
+L<PYX::Stack>,
+L<PYX::Utils>,
+L<Task::PYX>.
+
+=head1 REPOSITORY
+
+L<https://github.com/tupinek/PYX>
 
 =head1 AUTHOR
 
@@ -402,6 +422,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
